@@ -2,13 +2,13 @@ package LCFG::Build::Utils::OSXPkg;    # -*-cperl-*-
 use strict;
 use warnings;
 
-# $Id: OSXPkg.pm.in 27861 2015-06-24 10:10:43Z squinney@INF.ED.AC.UK $
+# $Id: OSXPkg.pm.in 29149 2015-11-06 15:21:39Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Utils/MacOSX.pm.in,v $
-# $Revision: 27861 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_0/lib/LCFG/Build/Utils/OSXPkg.pm.in $
-# $Date: 2015-06-24 11:10:43 +0100 (Wed, 24 Jun 2015) $
+# $Revision: 29149 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Utils/OSXPkg.pm.in $
+# $Date: 2015-11-06 15:21:39 +0000 (Fri, 06 Nov 2015) $
 
-our $VERSION = '0.6.0';
+our $VERSION = '0.6.1';
 
 use File::Copy ();
 use File::Spec ();
@@ -17,9 +17,9 @@ use LCFG::Build::Utils;
 use Sys::Hostname ();
 use Readonly;
 
-Readonly my $CMAKE => '/usr/bin/cmake';
-Readonly my $MAKE => '/usr/bin/make';
-Readonly my $PKGBUILD => '/usr/bin/pkgbuild';
+Readonly my $CMAKE => 'cmake';
+Readonly my $MAKE => 'make';
+Readonly my $PKGBUILD => 'pkgbuild';
 
 sub build {
   my ( $self, $outdir, $tarfile, $dirname,
@@ -116,7 +116,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Utils::OSXPkg version 0.6.0
+    This documentation refers to LCFG::Build::Utils::OSXPkg version 0.6.1
 
 =head1 DESCRIPTION
 
